# Product Engineer - Store

<p class="description">You will lead the technical, product, and operational development of the store.</p>

## Details of the Role

- Location: Remote (preference for UTC-6 to UTC+5).
- Type of work: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501#494af1f358794028beb4b7697b5d3102)).
- Level: [4 or above](https://docs.google.com/spreadsheets/d/1dDdPD-flNXlgZ0E3ZxVvCDx27RFuhVWJrcfcjNu_I8k/edit#gid=0).
- We're a remote company, we prefer asynchronous communication over meetings.
- We work independently, the rest of us won't know what you're doing day-to-day unless you tell us.

## About the company

MUI started with Material UI, the most successful React implementation of Google's Material Design.
We have gained a large following, thanks to our focus on Material Design fidelity, our obsession with details, on offering a large number of components, our community engagement, and by carefully improving the DX.
Today, countless teams and organizations rely on our open-source libraries to build their design system.

A couple of years ago, we started to expand our suite of products.
We released [MUI X](/x/), a collection of advanced components; [MUI Design kits](/design-kits/), the MUI components available for Figma, Sketch, etc.; and also host [Templates](/templates/), a set of pre-built UI kits.
We've seen rapid growth with all of them (2-3x per year) and we have more to come.
We are building [a low-code platform](https://mui.com/toolpad/) for developers to significantly increase the speed and lower the barrier for creating simple CRUD/dashboard UIs with MUI.

We are a fully distributed team, spread across multiple time zones.
We work mainly asynchronously, relying mostly on written collaboration.
Every contributor has the freedom to define how they work — the rest of us won't know what you're doing day-to-day unless you tell us.
For additional details about the MUI team and culture, you can check our [careers](/careers/) and [about](/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

Both our open-source community and our premium products are growing fast (x2 YoY).
We need talented people to keep that going!

The development and operations of the store are currently almost exclusively run by the executive team of the company (the co-founders).
This team doesn't have enough bandwidth, the store doesn't receive the care it deserves.
You will be responsible to step up and carry forward the development of the store on new fronts.

### Why this is interesting

You will get the opportunity to work on many different topics.

Our solution empowers React developers to build awesome applications faster – we see millions of developers on MUI's docs every year, one million a month.

## About the role

### What you'll do on a day-to-day basis

Depending on the day, you'll:

- Take initiatives to grow the sales of the templates
- Define the product direction
- Review new items submitted by the contributors to be hosted on the marketplace
- Fix root problems raised by store customers on the support channels
- Take care of operational needs, e.g. automate payouts, create sales reports

### Here are a few initiatives you might work on

Tasks that you might work on once you join:

- Explore ways to provide a theme builder/sell themes on the platform that deeply integrate with MUI Core and the documentation.
- Develop the SEA & SEO strategy, create new blog posts, try retargeting, Google Ads, etc.
- Improve the fulfillment workflow of MUI X Pro & Premium.
- Develop a Figma plugin & backend to push [MUI for Figma](https://mui.com/store/items/figma-react/) to reduce the collaboration friction between designers and developers.
- Add a search page to scale the hosting to more items from contributors.
- Revamp the design of the store to match the new brand of mui.com.
- Migrate the store from Gatsby to Next.js or Remix. Gatsby was introduced at a point in time when it had more downloads than Next.js. Our CEO has experience with Next.js since 2017 but wanted to ensure that MUI was supporting Gatsby well too.
  This requirement [is no longer relevant](https://npm-stat.com/charts.html?package=next&package=gatsby), and since the DX of Next.js is significantly better, time to migrate.

## About you

We're looking for someone with strong development skills, and more important than specific technical skills a strong problem solver who loves to learn new things. Details matter to you.
This role is perfect for you if you are curious, have tenacity, enjoy tacking risk, and care about design.
You are a [manager of one](https://signalvnoise.com/posts/1430-hire-managers-of-one).

### Skills you should have

- **Expertise in modern JavaScript ecosystem.** The store is currently build on WooCommerce so expertise in WordPress/PHP could help. Our backend technology of choice is Node.js.
- **A track record of demonstrating an eye for product and solving real-world user problems**. If you have a knack for solving problems at the root cause, finding boring solutions, we want you on our team.
- **Strong written and verbal communication skills**.
  As part of the team, you'll interface both directly and indirectly with community members and enterprise customers, and contribute to user documentation. Clear communication is fundamental in creating intuitive and compelling resources.
- **Ability to dive into complex problems**.
  You should be able to quickly assess, understand, and iterate upon aspects of our codebase.
- **Ready and willing to ask and answer questions**.
  If you're comfortable saying you're unsure, asking for help; but equally reaching out to assist others, you'll be an incredible addition to our team. We thrive because of continuous learning. First-time mistakes should be celebrated, not blamed.
- **Avoid monolithic deliverables**.
  You scope and stage your work into well-defined milestones to ship.

### What it would be nice if you had, but isn't required

- **Has or is pursuing a business side project**. You owned a side project generating revenues on the side of your full-time job. You were doing whatever was necessary to solve people's pain.

## Benefits & Compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person that can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](/careers/#perks-amp-benefits) page.

## How to apply?

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/e641bac3-5538-4ec8-8d73-eaa1a03704d6/application?utm_source=ZNRrPGBkqO)
